==> blesta-4.12.3.zip: blesta/components/modules/universal_module/language/en_us/universal_module.php <==
<?php
/**
 * en_us language for the universal module
 */

// Tooltips
$lang['UniversalModule.!tooltip.option_heading_field_label'] = 'This is the text that appears directly above the form field.';
$lang['UniversalModule.!tooltip.option_heading_field_name'] = 'This is the hidden form field name. Use qty to create a quantity field.';
$lang['UniversalModule.!tooltip.option_heading_field_type'] = 'This is the type of form field that will be displayed.';
$lang['UniversalModule.!tooltip.option_heading_field_required'] = 'Select yes to require this field. Note that special validation rules can be used for this field under Input Rules.';
$lang['UniversalModule.!tooltip.option_heading_field_encrypt'] = 'Selecting yes will cause the field data to be stored encrypted. The data will be unencrypted automatically for display when necessary.';
$lang['UniversalModule.!tooltip.option_heading_field_values'] = 'Enter values in the following format: field1:Field Name 1|field2:Field Name 2|field3:Field Name 3';

$lang['UniversalModule.!tooltip.option_heading_notice_notice'] = 'Enter the URL to post to, or the email address to email for this action.';
$lang['UniversalModule.!tooltip.option_heading_notice_code'] = 'If posting to a URL, you may enter an HTTP Code that designates a successful response.';
$lang['UniversalModule.!tooltip.option_heading_notice_response'] = 'If posting to a URL, you may enter a word or phrase contained in the response that indicates a success.';


// Basics
$lang['UniversalModule.name'] = 'Universal Module';
$lang['UniversalModule.description'] = 'A dynamic module meant to adapt to most users\' custom needs.';
$lang['UniversalModule.module_row'] = 'Product';
$lang['UniversalModule.module_row_plural'] = 'Products';

// Module management
$lang['UniversalModule.add_module_row'] = 'Add Product';
$lang['UniversalModule.manage.module_rows_title'] = 'Products';
$lang['UniversalModule.manage.module_rows_heading.name'] = 'Product Label';
$lang['UniversalModule.manage.module_rows_heading.options'] = 'Options';
$lang['UniversalModule.manage.module_rows.edit'] = 'Edit';
$lang['UniversalModule.manage.module_rows.delete'] = 'Delete';
$lang['UniversalModule.manage.module_rows.confirm_delete'] = 'Are you sure you want to delete this product?';
$lang['UniversalModule.manage.module_rows_no_results'] = 'There are no products.';

// Add module row
$lang['UniversalModule.add_row.box_title'] = 'Add Product';
$lang['UniversalModule.add_row.module_title'] = 'Module Options';
$lang['UniversalModule.add_row.name'] = 'Name';
$lang['UniversalModule.add_row.notice_name'] = 'Notice';
$lang['UniversalModule.add_row.notice_notice'] = 'Post URL/Email';
$lang['UniversalModule.add_row.notice_code'] = 'HTTP Code';
$lang['UniversalModule.add_row.notice_response'] = 'Response Contains';
$lang['UniversalModule.add_row.email_notification'] = 'Email Notification';

$lang['UniversalModule.add_row.package_title'] = 'Package Options';
$lang['UniversalModule.add_row.package_field_btn'] = 'Add Package Option';
$lang['UniversalModule.add_row.package_field_label'] = 'Label';
$lang['UniversalModule.add_row.package_field_name'] = 'Name';
$lang['UniversalModule.add_row.package_field_type'] = 'Type';
$lang['UniversalModule.add_row.package_field_values'] = 'Values';
$lang['UniversalModule.add_row.package_field_required'] = 'Required';
$lang['UniversalModule.add_row.package_field_encrypt'] = 'Encrypt';
$lang['UniversalModule.add_row.remove_package_field'] = 'Remove';
$lang['UniversalModule.add_row.package_rules'] = 'Input Rules';
$lang['UniversalModule.add_row.package_email_from'] = 'From Email';
$lang['UniversalModule.add_row.package_email_subject'] = 'Subject';
$lang['UniversalModule.add_row.package_email_html'] = 'HTML';
$lang['UniversalModule.add_row.package_email_text'] = 'Text';

$lang['UniversalModule.add_row.service_title'] = 'Service Options';
$lang['UniversalModule.add_row.service_field_btn'] = 'Add Service Option';
$lang['UniversalModule.add_row.service_field_label'] = 'Label';
$lang['UniversalModule.add_row.service_field_name'] = 'Name';
$lang['UniversalModule.add_row.service_field_type'] = 'Type';
$lang['UniversalModule.add_row.service_field_values'] = 'Values';
$lang['UniversalModule.add_row.service_field_required'] = 'Required';
$lang['UniversalModule.add_row.service_field_encrypt'] = 'Encrypt';
$lang['UniversalModule.add_row.remove_service_field'] = 'Remove';
$lang['UniversalModule.add_row.service_rules'] = 'Input Rules';
$lang['UniversalModule.add_row.service_email_from'] = 'From Email';
$lang['UniversalModule.add_row.service_email_subject'] = 'Subject';
$lang['UniversalModule.add_row.service_email_html'] = 'HTML';
$lang['UniversalModule.add_row.service_email_text'] = 'Text';

$lang['UniversalModule.add_row.add_btn'] = 'Add Product';

// Edit module row
$lang['UniversalModule.edit_row.box_title'] = 'Edit Product';
$lang['UniversalModule.edit_row.module_title'] = 'Module Options';
$lang['UniversalModule.edit_row.name'] = 'Name';
$lang['UniversalModule.edit_row.notice_name'] = 'Notice';
$lang['UniversalModule.edit_row.notice_notice'] = 'Post URL/Email';
$lang['UniversalModule.edit_row.notice_code'] = 'HTTP Code';
$lang['UniversalModule.edit_row.notice_response'] = 'Response Contains';
$lang['UniversalModule.edit_row.email_notification'] = 'Email Notification';

$lang['UniversalModule.edit_row.package_title'] = 'Package Options';
$lang['UniversalModule.edit_row.package_field_btn'] = 'Add Package Option';
$lang['UniversalModule.edit_row.package_field_label'] = 'Label';
$lang['UniversalModule.edit_row.package_field_name'] = 'Name';
$lang['UniversalModule.edit_row.package_field_type'] = 'Type';
$lang['UniversalModule.edit_row.package_field_values'] = 'Values';
$lang['UniversalModule.edit_row.package_field_required'] = 'Required';
$lang['UniversalModule.edit_row.package_field_encrypt'] = 'Encrypt';
$lang['UniversalModule.edit_row.remove_package_field'] = 'Remove';
$lang['UniversalModule.edit_row.package_rules'] = 'Input Rules';
$lang['UniversalModule.edit_row.package_email_from'] = 'From Email';
$lang['UniversalModule.edit_row.package_email_subject'] = 'Subject';
$lang['UniversalModule.edit_row.package_email_html'] = 'HTML';
$lang['UniversalModule.edit_row.package_email_text'] = 'Text';

$lang['UniversalModule.edit_row.service_title'] = 'Service Options';
$lang['UniversalModule.edit_row.service_field_btn'] = 'Add Service Option';
$lang['UniversalModule.edit_row.service_field_label'] = 'Label';
$lang['UniversalModule.edit_row.service_field_name'] = 'Name';
$lang['UniversalModule.edit_row.service_field_type'] = 'Type';
$lang['UniversalModule.edit_row.service_field_values'] = 'Values';
$lang['UniversalModule.edit_row.service_field_required'] = 'Required';
$lang['UniversalModule.edit_row.service_field_encrypt'] = 'Encrypt';
$lang['UniversalModule.edit_row.remove_service_field'] = 'Remove';
$lang['UniversalModule.edit_row.service_rules'] = 'Input Rules';
$lang['UniversalModule.edit_row.service_email_from'] = 'From Email';
$lang['UniversalModule.edit_row.service_email_subject'] = 'Subject';
$lang['UniversalModule.edit_row.service_email_html'] = 'HTML';
$lang['UniversalModule.edit_row.service_email_text'] = 'Text';

$lang['UniversalModule.edit_row.add_btn'] = 'Edit Product';

// Package notices
$lang['UniversalModule.getpackagenotices.add'] = 'Add';
$lang['UniversalModule.getpackagenotices.edit'] = 'Edit';

// Service notices
$lang['UniversalModule.getservicenotices.add'] = 'Add';
$lang['UniversalModule.getservicenotices.edit'] = 'Edit';
$lang['UniversalModule.getservicenotices.suspend'] = 'Suspend';
$lang['UniversalModule.getservicenotices.unsuspend'] = 'Unsuspend';
$lang['UniversalModule.getservicenotices.cancel'] = 'Cancel';
$lang['UniversalModule.getservicenotices.renew'] = 'Renew';
$lang['UniversalModule.getservicenotices.package_change'] = 'Package Change';

// Field types supported
$lang['UniversalModule.getfieldtypes.text'] = 'Text';
$lang['UniversalModule.getfieldtypes.textarea'] = 'Textarea';
$lang['UniversalModule.getfieldtypes.password'] = 'Password';
$lang['UniversalModule.getfieldtypes.select'] = 'Select';
$lang['UniversalModule.getfieldtypes.radio'] = 'Radio';
$lang['UniversalModule.getfieldtypes.checkbox'] = 'Checkbox';
$lang['UniversalModule.getfieldtypes.hidden'] = 'Hidden';
$lang['UniversalModule.getfieldtypes.secret'] = 'Secret';

// Misc
$lang['UniversalModule.true'] = 'Yes';
$lang['UniversalModule.false'] = 'No';
$lang['UniversalModule.getPackageFields.empty_module_row'] = 'No Universal products exist. <a href="%1$s">Create one.</a>'; // %1$s is the URI to add a product for the universal module

// Errors
$lang['UniversalModule.!error.package_notice_add.failed'] = 'The module failed communicating with the remote server when attempting to create the package.';
$lang['UniversalModule.!error.package_notice_edit.failed'] = 'The module failed communicating with the remote server when attemptined to update the package.';
$lang['UniversalModule.!error.service_notice_add.failed'] = 'The module failed communicating with the remote server when attempting to provision the service.';
$lang['UniversalModule.!error.service_notice_edit.failed'] = 'The module failed communicating with the remote server when attempting to update the service.';

$lang['UniversalModule.!error.service_notice_cancel.failed'] = 'The module failed communicating with the remote server when attempting to cancel the service.';
$lang['UniversalModule.!error.service_notice_suspend.failed'] = 'The module failed communicating with the remote server when attempting to suspend the service.';
$lang['UniversalModule.!error.service_notice_unsuspend.failed'] = 'The module failed communicating with the remote server when attempting to unsuspend the service.';
$lang['UniversalModule.!error.service_notice_renew.failed'] = 'The module failed communicating with the remote server when attempting to renew the service.';
$lang['UniversalModule.!error.service_notice_package_change.failed'] = 'The module failed communicating with the remote server when attempting to update the package/term assigned to the service.';

$lang['UniversalModule.!error.package_field.required'] = '%1$s is required.'; // %1$s is the label for the required package field
$lang['UniversalModule.!error.service_field.required'] = '%1$s is required.'; // %1$s is the label for the required service field

$lang['UniversalModule.!error.name.empty'] = 'Product name is required.';
$lang['UniversalModule.!error.package_email_from.required'] = 'From address is required for package email notification.';
$lang['UniversalModule.!error.service_email_from.required'] = 'From address is required for service email notification.';
$lang['UniversalModule.!error.module_row.invalid'] = 'You must specify a universal module product.';

==> blesta-5.3.1.zip: blesta/components/modules/universal_module/language/en_us/universal_module.php <==
<?php
/**
 * en_us language for the universal module
 */

// Tooltips
$lang['UniversalModule.!tooltip.option_heading_field_label'] = 'This is the text that appears directly above the form field.';
$lang['UniversalModule.!tooltip.option_heading_field_name'] = 'This is the hidden form field name. Use qty to create a quantity field.';
$lang['UniversalModule.!tooltip.option_heading_field_type'] = 'This is the type of form field that will be displayed. See Values tooltip for how to define values for checkbox, radio, and select fields.';
$lang['UniversalModule.!tooltip.option_heading_field_required'] = 'Select yes to require this field. Note that special validation rules can be used for this field under Input Rules.';
$lang['UniversalModule.!tooltip.option_heading_field_encrypt'] = 'Selecting yes will cause the field data to be stored encrypted. The data will be unencrypted automatically for display when necessary.';
$lang['UniversalModule.!tooltip.option_heading_field_values'] = 'For checkbox, radio, and select fields enter values in the following format: field1:Field Name 1|field2:Field Name 2|field3:Field Name 3';

$lang['UniversalModule.!tooltip.option_heading_notice_notice'] = 'Enter the URL to post to, or the email address to email for this action.';
$lang['UniversalModule.!tooltip.option_heading_notice_code'] = 'If posting to a URL, you may enter an HTTP Code that designates a successful response.';
$lang['UniversalModule.!tooltip.option_heading_notice_response'] = 'If posting to a URL, you may enter a word or phrase contained in the response that indicates a success.';


// Basics
$lang['UniversalModule.name'] = 'Universal Module';
$lang['UniversalModule.description'] = 'A dynamic module meant to adapt to most users\' custom needs.';
$lang['UniversalModule.module_row'] = 'Product';
$lang['UniversalModule.module_row_plural'] = 'Products';

// Module management
$lang['UniversalModule.add_module_row'] = 'Add Product';
$lang['UniversalModule.manage.module_rows_title'] = 'Products';
$lang['UniversalModule.manage.module_rows_heading.name'] = 'Product Label';
$lang['UniversalModule.manage.module_rows_heading.options'] = 'Options';
$lang['UniversalModule.manage.module_rows.edit'] = 'Edit';
$lang['UniversalModule.manage.module_rows.delete'] = 'Delete';
$lang['UniversalModule.manage.module_rows.confirm_delete'] = 'Are you sure you want to delete this product?';
$lang['UniversalModule.manage.module_rows_no_results'] = 'There are no products.';

// Add module row
$lang['UniversalModule.add_row.box_title'] = 'Add Product';
$lang['UniversalModule.add_row.module_title'] = 'Module Options';
$lang['UniversalModule.add_row.name'] = 'Name';
$lang['UniversalModule.add_row.notice_name'] = 'Notice';
$lang['UniversalModule.add_row.notice_notice'] = 'Post URL/Email';
$lang['UniversalModule.add_row.notice_code'] = 'HTTP Code';
$lang['UniversalModule.add_row.notice_response'] = 'Response Contains';
$lang['UniversalModule.add_row.email_notification'] = 'Email Notification';

$lang['UniversalModule.add_row.package_title'] = 'Package Options';
$lang['UniversalModule.add_row.package_field_btn'] = 'Add Package Option';
$lang['UniversalModule.add_row.package_field_label'] = 'Label';
$lang['UniversalModule.add_row.package_field_name'] = 'Name';
$lang['UniversalModule.add_row.package_field_type'] = 'Type';
$lang['UniversalModule.add_row.package_field_values'] = 'Values';
$lang['UniversalModule.add_row.package_field_required'] = 'Required';
$lang['UniversalModule.add_row.package_field_encrypt'] = 'Encrypt';
$lang['UniversalModule.add_row.remove_package_field'] = 'Remove';
$lang['UniversalModule.add_row.package_rules'] = 'Input Rules';
$lang['UniversalModule.add_row.package_email_from'] = 'From Email';
$lang['UniversalModule.add_row.package_email_subject'] = 'Subject';
$lang['UniversalModule.add_row.package_email_html'] = 'HTML';
$lang['UniversalModule.add_row.package_email_text'] = 'Text';

$lang['UniversalModule.add_row.service_title'] = 'Service Options';
$lang['UniversalModule.add_row.service_field_btn'] = 'Add Service Option';
$lang['UniversalModule.add_row.service_field_label'] = 'Label';
$lang['UniversalModule.add_row.service_field_name'] = 'Name';
$lang['UniversalModule.add_row.service_field_type'] = 'Type';
$lang['UniversalModule.add_row.service_field_values'] = 'Values';
$lang['UniversalModule.add_row.service_field_required'] = 'Required';
$lang['UniversalModule.add_row.service_field_encrypt'] = 'Encrypt';
$lang['UniversalModule.add_row.remove_service_field'] = 'Remove';
$lang['UniversalModule.add_row.service_rules'] = 'Input Rules';
$lang['UniversalModule.add_row.service_email_from'] = 'From Email';
$lang['UniversalModule.add_row.service_email_subject'] = 'Subject';
$lang['UniversalModule.add_row.service_email_html'] = 'HTML';
$lang['UniversalModule.add_row.service_email_text'] = 'Text';

$lang['UniversalModule.add_row.add_btn'] = 'Add Product';

// Edit module row
$lang['UniversalModule.edit_row.box_title'] = 'Edit Product';
$lang['UniversalModule.edit_row.module_title'] = 'Module Options';
$lang['UniversalModule.edit_row.name'] = 'Name';
$lang['UniversalModule.edit_row.notice_name'] = 'Notice';
$lang['UniversalModule.edit_row.notice_notice'] = 'Post URL/Email';
$lang['UniversalModule.edit_row.notice_code'] = 'HTTP Code';
$lang['UniversalModule.edit_row.notice_response'] = 'Response Contains';
$lang['UniversalModule.edit_row.email_notification'] = 'Email Notification';

$lang['UniversalModule.edit_row.package_title'] = 'Package Options';
$lang['UniversalModule.edit_row.package_field_btn'] = 'Add Package Option';
$lang['UniversalModule.edit_row.package_field_label'] = 'Label';
$lang['UniversalModule.edit_row.package_field_name'] = 'Name';
$lang['UniversalModule.edit_row.package_field_type'] = 'Type';
$lang['UniversalModule.edit_row.package_field_values'] = 'Values';
$lang['UniversalModule.edit_row.package_field_required'] = 'Required';
$lang['UniversalModule.edit_row.package_field_encrypt'] = 'Encrypt';
$lang['UniversalModule.edit_row.remove_package_field'] = 'Remove';
$lang['UniversalModule.edit_row.package_rules'] = 'Input Rules';
$lang['UniversalModule.edit_row.package_email_from'] = 'From Email';
$lang['UniversalModule.edit_row.package_email_subject'] = 'Subject';
$lang['UniversalModule.edit_row.package_email_html'] = 'HTML';
$lang['UniversalModule.edit_row.package_email_text'] = 'Text';

$lang['UniversalModule.edit_row.service_title'] = 'Service Options';
$lang['UniversalModule.edit_row.service_field_btn'] = 'Add Service Option';
$lang['UniversalModule.edit_row.service_field_label'] = 'Label';
$lang['UniversalModule.edit_row.service_field_name'] = 'Name';
$lang['UniversalModule.edit_row.service_field_type'] = 'Type';
$lang['UniversalModule.edit_row.service_field_values'] = 'Values';
$lang['UniversalModule.edit_row.service_field_required'] = 'Required';
$lang['UniversalModule.edit_row.service_field_encrypt'] = 'Encrypt';
$lang['UniversalModule.edit_row.remove_service_field'] = 'Remove';
$lang['UniversalModule.edit_row.service_rules'] = 'Input Rules';
$lang['UniversalModule.edit_row.service_email_from'] = 'From Email';
$lang['UniversalModule.edit_row.service_email_subject'] = 'Subject';
$lang['UniversalModule.edit_row.service_email_html'] = 'HTML';
$lang['UniversalModule.edit_row.service_email_text'] = 'Text';

$lang['UniversalModule.edit_row.add_btn'] = 'Edit Product';

// Package notices
$lang['UniversalModule.getpackagenotices.add'] = 'Add';
$lang['UniversalModule.getpackagenotices.edit'] = 'Edit';

// Service notices
$lang['UniversalModule.getservicenotices.add'] = 'Add';
$lang['UniversalModule.getservicenotices.edit'] = 'Edit';
$lang['UniversalModule.getservicenotices.suspend'] = 'Suspend';
$lang['UniversalModule.getservicenotices.unsuspend'] = 'Unsuspend';
$lang['UniversalModule.getservicenotices.cancel'] = 'Cancel';
$lang['UniversalModule.getservicenotices.renew'] = 'Renew';
$lang['UniversalModule.getservicenotices.package_change'] = 'Package Change';

// Field types supported
$lang['UniversalModule.getfieldtypes.text'] = 'Text';
$lang['UniversalModule.getfieldtypes.textarea'] = 'Textarea';
$lang['UniversalModule.getfieldtypes.password'] = 'Password';
$lang['UniversalModule.getfieldtypes.select'] = 'Select';
$lang['UniversalModule.getfieldtypes.radio'] = 'Radio';
$lang['UniversalModule.getfieldtypes.checkbox'] = 'Checkbox';
$lang['UniversalModule.getfieldtypes.hidden'] = 'Hidden';
$lang['UniversalModule.getfieldtypes.secret'] = 'Secret';

// Misc
$lang['UniversalModule.true'] = 'Yes';
$lang['UniversalModule.false'] = 'No';
$lang['UniversalModule.getPackageFields.empty_module_row'] = 'No Universal products exist. <a href="%1$s">Create one.</a>'; // %1$s is the URI to add a product for the universal module

// Errors
$lang['UniversalModule.!error.package_notice_add.failed'] = 'The module failed communicating with the remote server when attempting to create the package.';
$lang['UniversalModule.!error.package_notice_edit.failed'] = 'The module failed communicating with the remote server when attemptined to update the package.';
$lang['UniversalModule.!error.service_notice_add.failed'] = 'The module failed communicating with the remote server when attempting to provision the service.';
$lang['UniversalModule.!error.service_notice_edit.failed'] = 'The module failed communicating with the remote server when attempting to update the service.';

$lang['UniversalModule.!error.service_notice_cancel.failed'] = 'The module failed communicating with the remote server when attempting to cancel the service.';
$lang['UniversalModule.!error.service_notice_suspend.failed'] = 'The module failed communicating with the remote server when attempting to suspend the service.';
$lang['UniversalModule.!error.service_notice_unsuspend.failed'] = 'The module failed communicating with the remote server when attempting to unsuspend the service.';
$lang['UniversalModule.!error.service_notice_renew.failed'] = 'The module failed communicating with the remote server when attempting to renew the service.';
$lang['UniversalModule.!error.service_notice_package_change.failed'] = 'The module failed communicating with the remote server when attempting to update the package/term assigned to the service.';

$lang['UniversalModule.!error.package_field.required'] = '%1$s is required.'; // %1$s is the label for the required package field
$lang['UniversalModule.!error.service_field.required'] = '%1$s is required.'; // %1$s is the label for the required service field

$lang['UniversalModule.!error.name.empty'] = 'Product name is required.';
$lang['UniversalModule.!error.package_email_from.required'] = 'From address is required for package email notification.';
$lang['UniversalModule.!error.service_email_from.required'] = 'From address is required for service email notification.';
$lang['UniversalModule.!error.module_row.invalid'] = 'You must specify a universal module product.';
